// src/index.ts
import remarkExpressiveCode, { createRenderer } from "remark-expressive-code";
export * from "remark-expressive-code";
function astroExpressiveCode(options = {}) {
  return {
    name: "astro-expressive-code",
    hooks: {
      "astro:config:setup": async ({ config, updateConfig, injectScript }) => {
        const { customRenderer } = options ?? {};
        const ownPosition = config.integrations.findIndex((integration) => integration.name === "astro-expressive-code");
        const mdxPosition = config.integrations.findIndex((integration) => integration.name === "@astrojs/mdx");
        if (ownPosition > -1 && mdxPosition > -1 && mdxPosition < ownPosition) {
          throw new Error(
            `Incorrect integration order: To allow code blocks on MDX pages to use
						astro-expressive-code, please move astroExpressiveCode() before mdx()
						in the "integrations" array of your Astro config file.`.replace(/\s+/g, " ")
          );
        }
        const renderer = customRenderer ?? await createRenderer(options);
        const jsModules = renderer.jsModules ?? [];
        renderer.jsModules = [];
        const remarkExpressiveCodeOptions = {
          ...options,
          customRenderer: renderer
        };
        updateConfig({
          markdown: {
            syntaxHighlight: false,
            remarkPlugins: [[remarkExpressiveCode, remarkExpressiveCodeOptions]]
          }
        });
        jsModules.forEach((moduleCode) => injectScript("page", moduleCode));
      }
    }
  };
}
export {
  astroExpressiveCode
};
//# sourceMappingURL=index.js.map